@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -69,16 +69,18 @@ class ecLib
 	 */
 	public function setTaxType($type, $lang)
 	{
-		if ($type != $this->taxType){
+		if (empty($type)){			// 税タイプ未選択のとき
+			$this->taxRate = 0;
+			$this->taxType = '';
+		} else if ($type != $this->taxType){
 			// 税種別情報を取得
 			$ret = $this->db->getTaxType($type, $lang, $row);
 			if ($ret){
 				// 税率を取得
+				// 税率が取得できないときは0とする
 				$rate = $this->db->getTaxRate($row['tt_tax_rate_id']);
-				if ($rate != 0){
-					$this->taxRate = $rate;
-					$this->taxType = $type;
-				}
+				$this->taxRate = $rate;
+				$this->taxType = $type;
 			}
 		}
 	}
