@@ -50,9 +50,11 @@ class patTemplate_Modifier_Expression extends patTemplate_Modifier
         $params['expression'] = str_replace( '$self', "'$value'", $params['expression'] );
 
         @eval( '$result = '.$params['expression'].';' );
-        if( $result === true )
-            return $params['true'];
-        return $params['false'];
+        
+        if ($result === true) {
+            return str_replace( '$self', $value, $params['true'] );
+        }
+        return str_replace( '$self', $value, $params['false'] );
 	}
 }
 ?>
\ No newline at end of file
