@@ -16,7 +16,7 @@ CREATE TABLE _system_config (
 ) TYPE=innodb;
 INSERT INTO _system_config (sc_id,                         sc_value, sc_name,                sc_index) VALUES
 ('system_name',                 'Magic3',     'システム名称',                    0),
-('db_version',                  '2008042501', 'DBバージョン',                    1),
+('db_version',                  '2008050501', 'DBバージョン',                    1),
 ('server_id',                   '',           'サーバ識別用ID',                  2),
 ('default_lang',                'ja',         'デフォルト言語',                  3),
 ('multi_language',               '0',          '多言語対応',                      4),
@@ -297,17 +297,17 @@ CREATE TABLE _widget_log (
     PRIMARY KEY          (wl_serial)
 ) TYPE=innodb;
 
--- ナビゲーションバー項目マスター
+-- ナビゲーション項目マスター
 DROP TABLE IF EXISTS _nav_item;
 CREATE TABLE _nav_item (
     ni_id                INT            DEFAULT 0                     NOT NULL,      -- 項目ID
     ni_parent_id         INT            DEFAULT 0                     NOT NULL,      -- 親項目ID(親がないときは0)
-    ni_index             INT            DEFAULT 0                     NOT NULL,      -- 同じ親項目IDでの項目順(0～)
-    ni_nav_id            VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ナビゲーションバー識別ID
-    ni_task_id           VARCHAR(70)    DEFAULT ''                    NOT NULL,      -- 起動タスクID
+    ni_index             INT            DEFAULT 0                     NOT NULL,      -- 表示順(0～)、ni_parent_id=0のときは親間の表示順
+    ni_nav_id            VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ナビゲーション種別識別ID
+    ni_task_id           VARCHAR(70)    DEFAULT ''                    NOT NULL,      -- 起動タスクID、「_」で始まるときはリンクなし
     ni_param             VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 追加パラメータ
     ni_group_id          VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 項目グループ識別ID
-    ni_top_page_index    INT            DEFAULT 0                     NOT NULL,      -- トップ画面での表示順(0以外)
+    ni_view_control      INT            DEFAULT 0                     NOT NULL,      -- 表示位置制御、1のとき表示位置変更
     ni_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 名前
     ni_help_title        TEXT           DEFAULT ''                    NOT NULL,      -- ヘルプタイトル
     ni_help_body         TEXT           DEFAULT ''                    NOT NULL,      -- ヘルプ本文
@@ -317,21 +317,26 @@ CREATE TABLE _nav_item (
 ) TYPE=innodb;
 -- 管理画面メニューデータ
 INSERT INTO _nav_item
-(ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,    ni_group_id, ni_top_page_index, ni_name,    ni_visible) VALUES
-(1,     0,            0,        'admin_menu', '_page',            '',          0,                 '画面管理', true),
-(2,     1,            0,        'admin_menu', 'pagedef',     '',          1,                 '画面定義', true),
-(3,     1,            1,        'admin_menu', 'widgetlist',  '',          2,                 'ウィジェット管理', true),
-(4,     1,            2,        'admin_menu', 'templist',    '',          3,                 'テンプレート管理', true),
-(5,     1,            3,        'admin_menu', 'pageother',   '',          0,                 'その他', true),
-(6,     0,            1,        'admin_menu', '_login',            '',          0,                 'ログイン管理', true),
-(7,     6,            0,        'admin_menu', 'userlist',    '',          4,                 'ユーザ一覧', true),
-(8,     6,            1,        'admin_menu', 'loginstatus', '',          5,                 'ログイン状況', true),
-(9,     0,            2,        'admin_menu', '_config',            '',          0,                 'システム設定', true),
-(10,    9,            0,        'admin_menu', 'configsite',  '',          0,                 'サイト情報', true),
-(11,    9,            1,        'admin_menu', 'configsys',   '',          0,                 'システム情報', true),
-(12,    9,            2,        'admin_menu', 'initsystem',  '',          0,                 'システム初期化', true),
-(13,    0,            3,        'admin_menu', '_develop',     'develop',   0,                 '開発', false),
-(14,    13,           0,        'admin_menu', 'editsource',  'develop',   0,                 'ソース参照', false);
+(ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,                     ni_group_id, ni_param, ni_name,    ni_help_title, ni_help_body, ni_visible) VALUES
+(100,   0,            0,        'admin_menu', '_page',                        '',          '',       '画面管理', '画面管理', 'Webサイトのデザインや機能を管理します。', true),
+(101,   100,          0,        'admin_menu', 'pagedef',                       '',          '',           'PC用画面編集', 'PC用画面編集', 'PC用Webサイトの画面を作成します。', true),
+(102,   100,          1,        'admin_menu', 'pagedef_mobile',                '',          '',           '携帯用画面編集', '携帯用画面編集', '携帯用Webサイトの画面を作成します。', true),
+(103,   100,          2,        'admin_menu', 'widgetlist',                   '',          '',       'ウィジェット管理', 'ウィジェット管理', 'ウィジェットの管理を行います。', true),
+(104,   100,          3,        'admin_menu', 'templist',                     '',          '',       'テンプレート管理', 'テンプレート管理', 'テンプレートの管理を行います。', true),
+(105,   100,          4,        'admin_menu', 'pageother',                    '',          '',       'システムマスター管理', 'システムマスター管理', 'システムに関するデータの管理を行います。', true),
+(200,   0,            1,        'admin_menu', '_login',                       '',          '',       'ログイン管理', '', '', true),
+(201,   200,          0,        'admin_menu', 'userlist',                     '',          '',       'ユーザ一覧',   'ユーザ一覧', 'ログイン可能なユーザを管理します。', true),
+(202,   200,          1,        'admin_menu', 'loginstatus',                  '',          '',       'ログイン状況', 'ログイン状況', 'ユーザのログイン状況を表示します。', true),
+(300,   0,            2,        'admin_menu', '_config',                      '',          '',       'システム管理', '', '', true),
+(301,   300,          0,        'admin_menu', 'configsite',                   '',          '',       '基本情報', '基本情報', 'サイト運営者の設定を行います。メールアドレスは必須項目です。', true),
+(302,   300,          1,        'admin_menu', 'configsys',                    '',          '',       'システム情報', 'システム情報', 'システム全体の設定、運用状況を管理します。', true),
+(303,   300,          2,        'admin_menu', 'initsystem',                   '',          '',       'DBメンテナンス', 'DBメンテナンス', 'データの初期化などDBのメンテナンスを行います。', true),
+(304,   300,          3,        'admin_menu', 'showpage_custom_admin',         '',          '', '自由編集画面', '自由編集画面', '画面にウィジェットを載せて任意の管理用画面が作成できます。画面を作成するには、システム情報で開発モードをオンにし、PC用画面編集機能を使用します。', false),
+(1000,  0,            4,        'admin_menu', '_develop',                     'develop',   '',       '開発', '開発', '開発時に使用する機能です。', false),
+(1001,  1000,         0,        'admin_menu', 'editsource',                   'develop',   '',       'ソース参照', 'ソース参照', 'ソースコードが参照できます。', false),
+(1002,  1000,         1,        'admin_menu', 'createtable',                   'develop',   '',       'ユーザ定義テーブル', 'ユーザ定義テーブル', 'ユーザ定義のテーブルの作成、データの編集を行います。', false),
+(1100,  0,            11,       'admin_menu', '_others',                       '',          '',           'その他', '', '', true),
+(1101,  1100,         0,        'admin_menu', 'logout',                        '',          '',                  'ログアウト', 'ログアウト', '管理機能からログアウトします。', true);
 
 -- コンテンツ参照トラン
 DROP TABLE IF EXISTS _view_count;
