@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -86,7 +86,8 @@ class admin_mainWidgetlistWidgetContainer extends BaseWidgetContainer
 						$filePath = $searchPath . '/' . $file;
 						// ディレクトリかどうかチェック
 						if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath)
-								&& strncmp($file, '_', 1) != 0){		// 「_」で始まる名前のディレクトリは読み込まない
+								&& strncmp($file, '_', 1) != 0		// 「_」で始まる名前のディレクトリは読み込まない
+								&& strcmp($file, 'm') != 0){		// 携帯用のディレクトリ「m」は読み込まない
 							// DBに登録されていない場合は登録
 							for ($i = 0; $i < count($rows); $i++){
 								if ($file == $rows[$i]['wd_id']) break;
