@@ -1465,7 +1465,7 @@ class admin_mainDb extends BaseDb
 	 * @param array  $rows			取得レコード
 	 * @return						true=取得、false=取得せず
 	 */
-	function getTopPageItems($navId, &$rows)
+	/*function getTopPageItems($navId, &$rows)
 	{
 		$queryStr  = 'SELECT * FROM _nav_item ';
 		$queryStr .=   'WHERE ni_nav_id = ? ';
@@ -1474,7 +1474,7 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   'ORDER BY ni_top_page_index';
 		$retValue = $this->selectRecords($queryStr, array($navId), $rows);
 		return $retValue;
-	}
+	}*/
 	/**
 	 * ナビゲーションバー項目を取得
 	 *
